@@ -12,7 +12,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.803';
+our $VERSION = '1.804';
 
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
 
@@ -238,7 +238,7 @@ sub dequeue {
 
    $_Q->{_nb_flag} = 0;
 
-   return @_items if (defined $_cnt);
+   return @_items if (defined $_cnt && $_cnt ne '1');
    return $_buf;
 }
 
@@ -611,7 +611,7 @@ MCE::Shared::Queue - Hybrid-queue helper class
 
 =head1 VERSION
 
-This document describes MCE::Shared::Queue version 1.803
+This document describes MCE::Shared::Queue version 1.804
 
 =head1 SYNOPSIS
 
